local PileSeller = _G.PileSeller
local checkIcon = "|TInterface\\ACHIEVEMENTFRAME\\UI-Achievement-Criteria-Check:20:30|t"


local lastClicked 

function AddToList(item, list, found)
	t = list.wgt.text .. item
	if found then t = t .. checkIcon end
	t = t .. "|n"
	list.wgt:SetText(t)
	list.wgt.text = t
end

function PileSeller:PopulateList(list, items)
	list.wgt:SetText("")
	list.wgt.text = ""
	for i=1, #items do
		local found = nil
		item = select(2, GetItemInfo(items[i]))
		if list:GetName() == "PileSeller_ConfigFrame_SavedScrollContent" then found = psItemsSavedFound[items[i]] end
		AddToList(item, list, found or false)
	end
end


function PileSeller:ShowConfig(args)
	-- Default BasicFrameTemplateWithInset
	local switchTo = ""
	if args == "config" then switchTo = "Items"
	elseif args == "items" then switchTo = "Config" end

	if PileSeller.UIConfig then 
		if PileSeller.UIConfig:IsShown() then return 
		end
	end
	PileSeller.UIConfig = CreateFrame("Frame", "PileSeller_ConfigFrame", UIParent, "ThinBorderTemplate")
	PileSeller.UIConfig:SetFrameStrata("HIGH")
	PileSeller.UIConfig:SetSize(575, 400)
	PileSeller.UIConfig:SetPoint("RIGHT", UIParent, -100, 0)
	PlaySound("igCharacterInfoOpen");
	PileSeller:MakeMovable(PileSeller.UIConfig)

	-- Texture
	PileSeller.UIConfig.bg = PileSeller.UIConfig:CreateTexture()
	PileSeller.UIConfig.bg:SetAllPoints(PileSeller.UIConfig)
	PileSeller.UIConfig.bg:SetTexture(.1,.1,.1,.8)

	-- Title
	PileSeller.UIConfig.title = PileSeller.UIConfig:CreateFontString("PileSeller_ConfigFrame_Title", "OVERLAY", "GameFontHighlight")
	PileSeller.UIConfig.title:SetPoint("TOPLEFT", PileSeller.UIConfig, "TOPLEFT", 10, -10)
	PileSeller.UIConfig.title:SetText("|cFF" .. PileSeller.color .. "Pile|rSeller")

	-- Switch Mode
	PileSeller.UIConfig.switch = CreateFrame("Button", "PileSeller_ConfigFrame_SwitchButton", PileSeller.UIConfig, "GameMenuButtonTemplate")
	PileSeller.UIConfig.switch:SetPoint("TOPRIGHT", PileSeller.UIConfig, "TOPRIGHT", -30, -4)
	PileSeller.UIConfig.switch:SetSize(75, 26)
	PileSeller.UIConfig.switch:SetText(switchTo)
	PileSeller.UIConfig.switch:SetScript("OnClick", function()
		local t = PileSeller.UIConfig.switch:GetText()
		if t == "Items" then
			t = "Config"
			PileSeller:CreateItemsSection(PileSeller.UIConfig)
             PileSeller.UIConfig.tutorial:Show()
		elseif t == "Config" then
			t = "Items"
			CreateConfigSection(PileSeller.UIConfig)
             PileSeller.UIConfig.tutorial:Hide()
		end
		PileSeller.UIConfig.switch:SetText(t)
	end
    )
    
    -- Tutorial Button
    PileSeller.UIConfig.tutorial = CreateFrame("Button", "PileSeller_ConfigFrame_TutorialButton", PileSeller.UIConfig)
    PileSeller.UIConfig.tutorial:SetSize(50, 50)
    PileSeller.UIConfig.tutorial:SetPoint("BOTTOMRIGHT", PileSeller.UIConfig, "BOTTOMRIGHT", 15, -15)
    PileSeller.UIConfig.tutorial:SetNormalTexture("Interface\\TUTORIALFRAME\\TutorialFrame-QuestionMark")
    PileSeller.UIConfig.tutorial:SetHighlightTexture("Interface\\Buttons\\UI-Common-MouseHilight", "ADD")
    PileSeller.UIConfig.tutorial:SetScript("OnClick", function()
            PileSeller:ToggleTutorial(PileSeller.UIConfig)
        end
    )
    
    
    -- Tracking Button
    PileSeller.UIConfig.toggleTracking = CreateFrame("Button", "PileSeller_ConfigFrame_ToggleTracking", PileSeller.UIConfig, "GameMenuButtonTemplate")
    PileSeller.UIConfig.toggleTracking:SetPoint("TOP", PileSeller.UIConfig, "TOP", 0, 0)
    PileSeller.UIConfig.toggleTracking:SetSize(125, 26)
    PileSeller.UIConfig.toggleTracking:SetText(psSettings["trackSetting"] and "Stop tracking" or "Start tracking")
    PileSeller.UIConfig.toggleTracking:SetScript("OnClick", function()
        local b = PileSeller.UIConfig.toggleTracking:GetText() == "Start tracking"
        PileSeller:ToggleTracking(b)
        PileSeller.UIConfig.toggleTracking:SetText(psSettings["trackSetting"] and "Stop tracking" or "Start tracking")
    end
    )

	PileSeller.UIConfig.close = CreateFrame("Button", "PileSeller_ConfigFrame_CloseButton", PileSeller.UIConfig, "UIPanelCloseButton")
	PileSeller.UIConfig.close:SetPoint("TOPRIGHT", PileSeller.UIConfig)
	PileSeller.UIConfig.close:SetSize(34, 34)
	PileSeller.UIConfig.close:SetScript("OnClick", HideConfig)
	if args == "items" then
		PileSeller:CreateItemsSection(PileSeller.UIConfig)
	elseif args == "config" then		
		CreateConfigSection(PileSeller.UIConfig)
	end
end

function HideConfig()
	PileSeller.UIConfig:Hide()
	PlaySound("igCharacterInfoClose"); 
	--for i=1, #UISpecialFrames do
	--	if UISpecialFrames[i] == PileSeller.UIConfig:GetName() then 
	--		table.remove(UISpecialFrames, i) 
	--		break;
	--	end
	--end
end

function HideAllFromConfig(ui)
	-- By doing this I can find any other item in the frame
    -- Now I just hide all the things that I don't need
	local children = { ui:GetChildren() }
	for i=1, #children do
		local name = children[i]:GetName()
		local kid = 
            name == "PileSeller_ConfigFrame_CloseButton" or 
            name == "PileSeller_ConfigFrame_SwitchButton" or 
            name == "PileSeller_ConfigFrame_ToggleTracking" or 
            name == "PileSeller_ConfigFrame_TutorialButton" or
            (children[i]:GetName() == "PileSeller_ConfigFrame_ItemInfos" and not children[i]:IsVisible()) 
		if not kid then children[i]:Hide() end
	end
end

function CreateItemInfos(UIConfig)
	HideAllFromConfig(UIConfig)
	UIConfig.itemInfos = CreateFrame("Frame", "PileSeller_ConfigFrame_ItemInfos", UIConfig, "ThinBorderTemplate")
	UIConfig.itemInfos:SetPoint("RIGHT", UIConfig, -10, 0)
	UIConfig.itemInfos:SetSize(200, 300)
	UIConfig.itemInfos.bg = UIConfig.itemInfos:CreateTexture()
	UIConfig.itemInfos.bg:SetAllPoints(UIConfig.itemInfos)
	UIConfig.itemInfos.bg:SetTexture(.27,.27,.27,.8)

	UIConfig.itemInfos.item = CreateFrame("Frame", nil, UIConfig.itemInfos)
	UIConfig.itemInfos.item:SetSize(50, 50)
	UIConfig.itemInfos.item:SetPoint("TOP", UIConfig.itemInfos, 0, -10)
	UIConfig.itemInfos.item.tx = UIConfig.itemInfos.item:CreateTexture(nil, "BACKGROUND")
	UIConfig.itemInfos.item.tx:SetTexture("Interface\\Buttons\\UI-CheckBox-Up")
	UIConfig.itemInfos.item.tx:SetVertexColor(1,1,1,1)
	UIConfig.itemInfos.item.tx:SetAllPoints()
	
	UIConfig.itemInfos.item.itemName = UIConfig.itemInfos.item:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
	UIConfig.itemInfos.item.itemName:SetPoint("BOTTOM", UIConfig.itemInfos.item, "BOTTOM", 0, -50)
	UIConfig.itemInfos.item.itemName:SetText("item name")
	UIConfig.itemInfos.item.itemName:SetSize(175, 40)

	UIConfig.itemInfos.item.itemClass = UIConfig.itemInfos.item:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
	UIConfig.itemInfos.item.itemClass:SetPoint("BOTTOM", UIConfig.itemInfos.item.itemName, "BOTTOM", 0, -25)
	UIConfig.itemInfos.item.itemClass:SetText("|cFF" .. PileSeller.color .. "Item type: |rsubclass")

	UIConfig.itemInfos.item.itemValue = UIConfig.itemInfos.item:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
	UIConfig.itemInfos.item.itemValue:SetPoint("BOTTOM", UIConfig.itemInfos.item.itemClass, "BOTTOM", 0, -40, "TOP")
	UIConfig.itemInfos.item.itemValue:SetSize(175, 40)
	UIConfig.itemInfos.item.itemValue:SetText("|cFF" .. PileSeller.color .. "Item value: |rvalue")

	UIConfig.itemInfos.item.itemID = UIConfig.itemInfos.item:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
	UIConfig.itemInfos.item.itemID:SetPoint("BOTTOM", UIConfig.itemInfos.item.itemValue, "BOTTOM", 0, -25, "TOP")
	UIConfig.itemInfos.item.itemID:SetSize(175, 40)
	UIConfig.itemInfos.item.itemID:SetText("|cFF" .. PileSeller.color .. "Item id: |rvalue")

	UIConfig.itemInfos.item.removeFromList = CreateFrame("Button", nil, UIConfig.itemInfos.item, "GameMenuButtonTemplate")
	UIConfig.itemInfos.item.removeFromList:SetText("Remove from list")
	UIConfig.itemInfos.item.removeFromList:SetSize(125, 21)
	UIConfig.itemInfos.item.removeFromList:SetPoint("BOTTOM", UIConfig.itemInfos.item.itemID, "BOTTOM", 0, -80)

	UIConfig.itemInfos.item.toggleAlert = CreateFrame("Button", nil, UIConfig.itemInfos.item, "GameMenuButtonTemplate")
	UIConfig.itemInfos.item.toggleAlert:SetText("Set Alert")
	UIConfig.itemInfos.item.toggleAlert:SetSize(125, 21)
	UIConfig.itemInfos.item.toggleAlert:SetPoint("TOP", UIConfig.itemInfos.item.removeFromList, "TOP", 0, 25)

	UIConfig.itemInfos:Hide()
	--SetItemInfo(PileSeller.UIConfig.itemInfos.item, "60844")
end

function PileSeller:SetItemInfo(parent, item)
    parent:GetParent():Show()
	local n, l, q, _, _, _, c, _, _, i, v = GetItemInfo(item)

	-- l = item name
	-- c = item subclass (mount, helm...)
	-- i = texture
	-- v = vendor value
	-- q = quality
	--print(l)
	--print(c)
	--print(v)
	--print(q)
	qualities = {}
	qualities[0] = "9d9d9d"
	qualities[1] = "FFFFFF"
	qualities[2] = "1eff00"
	qualities[3] = "0070ff"
	qualities[4] = "a335ee"
	qualities[5] = "ff8000"
	qualities[6] = "e6cc80"
	if q >= 6 then q = qualities[6]
	else q = qualities[q] end

	local tx = parent.tx
	tx:SetTexture(i)
	tx:SetVertexColor(1,1,1,1)
	tx:SetAllPoints()

	local id = PileSeller:getID(l)

	parent.itemName:SetText(n)
	parent.itemClass:SetText("|cFF".. PileSeller.color .. "Item type:|r |cFF" .. q .. c .. "|r")
	parent.itemID:SetText("|cFF".. PileSeller.color .. "Item ID:|r " .. id)
	
	parent.removeFromList:SetScript("OnClick", function()
		local tableToGet = {}
		if lastClicked:GetName() == "PileSeller_ConfigFrame_SavedScrollContent" then tableToGet = psItemsSaved
		else tableToGet = psItems end

		for i=1, #tableToGet do
			if id == tableToGet[i] then
				tremove(tableToGet, i)
			end
		end
		
		PileSeller:PopulateList(lastClicked, tableToGet)
		PileSeller:CreateItemsSection(PileSeller.UIConfig)
	end
	)
	if lastClicked then 
        if lastClicked:GetName() then
            if lastClicked:GetName() == "PileSeller_ConfigFrame_ToSellScrollContent" then parent.toggleAlert:Hide()
            elseif lastClicked:GetName() == "PileSeller_ConfigFrame_SavedScrollContent" then
                parent.toggleAlert:Show()
                if psItemsAlert[id] then parent.toggleAlert:SetText("Remove Alert")
                else parent.toggleAlert:SetText("Set Alert") end
                parent.toggleAlert:SetScript("OnClick", function()
                    if parent.toggleAlert:GetText() == "Set Alert" then
                        psItemsAlert[id] = true
                        parent.toggleAlert:SetText("Remove Alert")
                    else psItemsAlert[id] = false end
                end
                )
            end
        end
    end

	local t = "|cFF".. PileSeller.color .. "Item value: |r"
	if v > 0 then
		local gold = math.floor(v / 100 / 100)
		local silver = math.floor((v / 100) % 100)
		local copper = math.floor(v % 100)
		if gold > 1 then t = t .. gold .. "|cFFFFD700g|r " end
		if silver > 1 then t = t .. silver .. "|cFFC0C0C0s|r " end
		if copper > 1 then t = t .. copper .. "|cFFCD7E32c|r" end
	else t = t .. "No value" end
	parent.itemValue:SetText(t)
end

function PileSeller:CreateItemsSection(UIConfig)
	CreateItemInfos(UIConfig)
	CreateSavedSection(UIConfig)
	CreateToSellSection(UIConfig)
end

function CreateSavedSection(UIConfig)	
	--[[SAVED SECTION]]--
	-- Button open saved
	if not UIConfig.btnSaved then 
		UIConfig.btnSaved = CreateFrame("Button", nil, UIConfig, "GameMenuButtonTemplate")
		UIConfig.btnSaved:SetPoint("TOPLEFT", UIConfig, "TOPLEFT", 25, -50)
		UIConfig.btnSaved:SetSize(26, 26)
		UIConfig.btnSaved:SetText("+")
	else UIConfig.btnSaved:Show() end

	-- Text Saved
	if not UIConfig.btnSaved.lblSaved then 
		UIConfig.btnSaved.lblSaved = UIConfig.btnSaved:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		UIConfig.btnSaved.lblSaved:SetPoint("LEFT", UIConfig.btnSaved, "RIGHT", 0, 0)
		UIConfig.btnSaved.lblSaved:SetText("Saved items list")
	else UIConfig.btnSaved.lblSaved:Show() end

	-- Scroll frame for the saved items
	if not UIConfig.savedScroll then 
		UIConfig.savedScroll = CreateFrame("ScrollFrame", "PileSellerConfigFrameScrollBar_Saved", UIConfig, "UIPanelScrollFrameTemplate")
		UIConfig.savedScroll:SetPoint("CENTER", UIConfig.btnSaved, "CENTER", 110, -70)
		UIConfig.savedScroll:SetSize(260, 120)
		UIConfig.savedScroll:Hide()
		UIConfig.savedScroll:SetClampedToScreen(true)

		-- Texture for some swag
		local tex = UIConfig.savedScroll:CreateTexture(nil, "BACKGROUND")
		tex:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
		tex:SetVertexColor(0,0,0,1)
		tex:SetAllPoints()

		UIConfig.savedScroll.border = CreateFrame("FRAME", nil, UIConfig.savedScroll)
		UIConfig.savedScroll.border:SetSize(260, 120)
		UIConfig.savedScroll.border:SetPoint("LEFT", UIConfig.savedScroll)
		UIConfig.savedScroll.border:SetBackdrop({
		bgFile = [[Interface\Buttons\WHITE8X8]], 
		edgeFile = [[Interface\Buttons\WHITE8X8]], 
		edgeSize = 1, 
		insets = {
			    left = 1,
			    right = 1,
			    top = 1,
			    bottom = 1
		  }
		})
		UIConfig.savedScroll.border:SetBackdropColor(.27,.27,.27, .3)
		UIConfig.savedScroll.border:SetBackdropBorderColor(0, 0, 0)
	elseif UIConfig.btnSaved:GetText() == "-" then UIConfig.savedScroll:Show()	end
	-- Actual content of the scroll frame
	if not UIConfig.savedScroll.content then 
		UIConfig.savedScroll.content = CreateFrame("Frame", "PileSeller_ConfigFrame_SavedScrollContent")
		UIConfig.savedScroll.content:SetSize(260, 95)
		UIConfig.savedScroll.content:SetPoint("LEFT", UIConfig.savedScroll, "LEFT", 0, 0)
	elseif UIConfig.btnSaved:GetText() == "-" then UIConfig.savedScroll.content:Show()	end
	-- Creating the text widget
	if not UIConfig.savedScroll.content.wgt then 
		UIConfig.savedScroll.content.wgt = CreateFrame("SimpleHTML", "PileSeller_ConfigFrame_SavedScrollContent_Text", UIConfig.savedScroll.content)
		UIConfig.savedScroll.content.wgt:SetFont('Fonts\\FRIZQT__.TTF', 11)
		UIConfig.savedScroll.content.wgt:SetSize(240, 11)
		UIConfig.savedScroll.content.wgt:SetPoint("LEFT", UIConfig.savedScroll.content, "LEFT", 10, 35)
		UIConfig.savedScroll.content.wgt:SetScript("OnHyperlinkEnter", function(self, _, link, ...)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
			GameTooltip:SetHyperlink(link)
			GameTooltip:Show()
		end
		)
		UIConfig.savedScroll.content.wgt:SetScript("OnHyperlinkLeave", function(self, _, link, ...)
			GameTooltip:Hide()
		end
		)
		UIConfig.savedScroll.content.wgt:SetScript("OnHyperlinkClick", function(self, _, link, ...)
			lastClicked = UIConfig.savedScroll.content
			PileSeller:CreateItemsSection(UIConfig)
			if IsShiftKeyDown() then
				ChatEdit_InsertLink(link)
			elseif IsControlKeyDown() then
				local id = PileSeller:getID(link)
				DressUpItemLink(id)
			end
			PileSeller:SetItemInfo(UIConfig.itemInfos.item, link)
		end
		)
		UIConfig.savedScroll.content.wgt.text = ""
	elseif UIConfig.btnSaved:GetText() == "-" then UIConfig.savedScroll.content.wgt:Show()	end
	-- Creating the add item bar
	if not UIConfig.txtAddSavedItem then 
		UIConfig.txtAddSavedItem = CreateFrame("EditBox", nil, UIConfig.savedScroll, "InputBoxInstructionsTemplate")
		UIConfig.txtAddSavedItem:SetSize(255, 21)
		UIConfig.txtAddSavedItem:SetPoint("LEFT", UIConfig.savedScroll, "LEFT", 5, -70)
		UIConfig.txtAddSavedItem:SetAutoFocus(false)
		UIConfig.txtAddSavedItem:SetScript("OnEscapePressed", function()
			UIConfig.txtAddSavedItem:ClearFocus()
		end
		)
	elseif UIConfig.btnSaved:GetText() == "-" then UIConfig.txtAddSavedItem:Show()	end


	-- Creating the add item button
	if not UIConfig.btnAddSavedItem then 
		UIConfig.btnAddSavedItem = CreateFrame("Button", nil, UIConfig.txtAddSavedItem, "GameMenuButtonTemplate")
		UIConfig.btnAddSavedItem:SetSize(26, 26)
		UIConfig.btnAddSavedItem:SetPoint("RIGHT", UIConfig.txtAddSavedItem, "RIGHT", 26, -1)
		UIConfig.btnAddSavedItem:SetText("+")
		UIConfig.btnAddSavedItem:SetScript("OnClick", function()
			local t = UIConfig.txtAddSavedItem:GetText()
			if t then
				if string.match(t, "item[%-?%d:]+") then
					PileSeller:addItem(t, psItemsSaved, UIConfig.savedScroll.content)
				else
					local l = string.len(t)
					for i=1, l do
						s = t:sub(i,i)
						if s < '0' or s > '9' then 
							UIConfig.txtAddSavedItem:SetText("-- ERROR --")
							return
						end
					end
					PileSeller:addItem(t, psItemsSaved, UIConfig.savedScroll.content)
					UIConfig.txtAddSavedItem:SetText("")
				end
			end
		end
		)
	elseif UIConfig.btnSaved:GetText() == "-" then UIConfig.btnAddSavedItem:Show()	end
	-- Binding the content to the scroll frame
	if not UIConfig.savedScroll:GetScrollChild() then
		UIConfig.savedScroll:SetScrollChild(UIConfig.savedScroll.content)
	end

	-- Binding the event for the button
	if not UIConfig.btnSaved:GetScript("OnClick") then
		UIConfig.btnSaved:SetScript("OnClick", function()
			if UIConfig.btnSaved:GetText() == "+" then
				UIConfig.btnToSell:SetPoint("TOPLEFT", UIConfig, "TOPLEFT", 25, -230)
				UIConfig.btnSaved:SetText("-")
				UIConfig.savedScroll:Show()
				PileSeller:PopulateList( UIConfig.savedScroll.content, psItemsSaved)
				--UIConfig.savedScroll:SetClampedToScreen(true)
			else
				UIConfig.btnToSell:SetPoint("TOPLEFT", UIConfig, "TOPLEFT", 25, -90)
				UIConfig.btnSaved:SetText("+")
				UIConfig.savedScroll:Hide()
				UIConfig.savedScroll.content.wgt:SetText("")
				UIConfig.savedScroll.content.wgt.text = ""
			end
		end
		)
	end
end

function CreateToSellSection(UIConfig)
	--[[TO SELL SECTION]]--
	-- Button open toSell
	if not UIConfig.btnToSell then
		UIConfig.btnToSell = CreateFrame("Button", nil, UIConfig, "GameMenuButtonTemplate")
		UIConfig.btnToSell:SetPoint("TOPLEFT", UIConfig, "TOPLEFT", 25, -90)
		UIConfig.btnToSell:SetSize(26, 26)
		UIConfig.btnToSell:SetText("+")
	else UIConfig.btnToSell:Show() end

	-- Text toSell
	if not UIConfig.lblToSell then
		UIConfig.btnToSell.lblToSell = UIConfig.btnToSell:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		UIConfig.btnToSell.lblToSell:SetPoint("LEFT", UIConfig.btnToSell, "RIGHT", 0, 0)
		UIConfig.btnToSell.lblToSell:SetText("Items to sell")
	else UIConfig.btnToSell.lblToSell:Show() end

	-- Scroll frame for the items to sell
	if not UIConfig.toSellScroll then
		UIConfig.toSellScroll = CreateFrame("ScrollFrame", "PileSeller_ConfigFrame_ToSellScroll", UIConfig, "UIPanelScrollFrameTemplate")
		UIConfig.toSellScroll:SetPoint("CENTER", UIConfig.btnToSell, "CENTER", 110, -70)
		UIConfig.toSellScroll:SetSize(260, 100)
		UIConfig.toSellScroll:Hide()
		UIConfig.toSellScroll:SetClampedToScreen(true)


		-- Texture for some swag
		local tex = UIConfig.toSellScroll:CreateTexture(nil, "BACKGROUND")
		tex:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
		tex:SetVertexColor(0,.0,0,1)
		tex:SetAllPoints()

		UIConfig.toSellScroll.border = CreateFrame("FRAME", nil, UIConfig.toSellScroll)
		UIConfig.toSellScroll.border:SetSize(260, 100)
		UIConfig.toSellScroll.border:SetPoint("LEFT", UIConfig.toSellScroll)
		UIConfig.toSellScroll.border:SetBackdrop({
		bgFile = [[Interface\Buttons\WHITE8X8]], 
		edgeFile = [[Interface\Buttons\WHITE8X8]], 
		edgeSize = 1, 
		insets = {
			    left = 1,
			    right = 1,
			    top = 1,
			    bottom = 1
		  }
		})
		UIConfig.toSellScroll.border:SetBackdropColor(.27,.27,.27, .3)
		UIConfig.toSellScroll.border:SetBackdropBorderColor(0, 0, 0)
	elseif UIConfig.btnToSell:GetText() == "-" then UIConfig.toSellScroll:Show() end

	-- Actual content of the scroll frame
	if not UIConfig.toSellScroll.content then
		UIConfig.toSellScroll.content = CreateFrame("Frame", "PileSeller_ConfigFrame_ToSellScrollContent")
		UIConfig.toSellScroll.content:SetSize(260, 100)
		UIConfig.toSellScroll.content:SetPoint("LEFT")		
	elseif UIConfig.btnToSell:GetText() == "-" then UIConfig.toSellScroll.content:Show() end

	-- Creating the text widget
	if not UIConfig.toSellScroll.content.wgt then
		UIConfig.toSellScroll.content.wgt = CreateFrame("SimpleHTML", "PileSeller_ConfigFrame_ToSellScroll_Text", UIConfig.toSellScroll.content)
		UIConfig.toSellScroll.content.wgt:SetFont('Fonts\\FRIZQT__.TTF', 11)
		UIConfig.toSellScroll.content.wgt:SetSize(175, 11)
		UIConfig.toSellScroll.content.wgt:SetPoint("LEFT", UIConfig.toSellScroll.content, "LEFT", 10, 35)
		UIConfig.toSellScroll.content.wgt:SetScript("OnHyperlinkEnter", function(self, _, link, ...)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
			GameTooltip:SetHyperlink(link)
			GameTooltip:Show()
		end
		)
		UIConfig.toSellScroll.content.wgt:SetScript("OnHyperlinkLeave", function(self, _, link, ...)
			GameTooltip:Hide()
		end
		)
		UIConfig.toSellScroll.content.wgt:SetScript("OnHyperlinkClick", function(self, _, link, ...)
			lastClicked = UIConfig.toSellScroll.content
			PileSeller:CreateItemsSection(UIConfig)
			PileSeller:SetItemInfo(UIConfig.itemInfos.item, link)
			if IsShiftKeyDown() then
				ChatEdit_InsertLink(link)
			elseif IsControlKeyDown() then
				local id = PileSeller:getID(link)
				DressUpItemLink(id)
			end
		end
		)
		UIConfig.toSellScroll.content.wgt.text = ""
	elseif UIConfig.btnToSell:GetText() == "-" then UIConfig.toSellScroll.content.wgt:Show() end

	-- Binding the content to the scroll frame
	if not UIConfig.toSellScroll:GetScrollChild() then
		UIConfig.toSellScroll:SetScrollChild(UIConfig.toSellScroll.content)
	end

	if not UIConfig.btnToSell:GetScript("OnClick") then
		UIConfig.btnToSell:SetScript("OnClick", function()
			if UIConfig.btnToSell:GetText() == "+" then
				UIConfig.btnToSell:SetText("-")
				UIConfig.toSellScroll:Show()
				PileSeller:PopulateList(UIConfig.toSellScroll.content, psItems)
			else
				UIConfig.btnToSell:SetText("+")
				UIConfig.toSellScroll:Hide()
				UIConfig.toSellScroll.content.wgt:SetText("")
				UIConfig.toSellScroll.content.wgt.text = ""
			end
		end
		)
	end
end

function CreateConfigSection(UIConfig)
	HideAllFromConfig(UIConfig)
	local y = -30
	for i = 1, #PileSeller.settings do
	    PileSeller:CreateCheckButton(PileSeller.settings[i], UIConfig, y)
		y = y - 25
	end
end

function PileSeller:CreateCheckButton(check, parent, y)
	local name = check.name
	local sub = check.sub and 50 or 30
	local text = check.text
	parent[name] = CreateFrame("CheckButton", "chk" .. name, UIConfig, "UICheckButtonTemplate")
	parent[name]:SetChecked(psSettings[name])
	if not check.f then
		parent[name]:SetScript("OnClick", function()
			local b = parent[name]:GetChecked()
			psSettings[name] = parent[name]:GetChecked()
			if check.masterOf then ToggleCheckAndText(parent, check.masterOf, b) end
		end
		)
	else parent[name]:SetScript("OnClick", check.f) end
	parent[name]:SetPoint("TOPLEFT", parent, sub, y)
	local width = parent[name]:GetWidth()
	
	parent[name].lbl = parent[name]:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	parent[name].lbl:SetPoint("LEFT", parent[name], width, 0, "RIGHT")
	parent[name].lbl:SetText(text)
    parent[name].lbl:SetTextColor(253/255, 209/255, 22/255,1)
    if check.slaveOf then ToggleCheckAndText(parent, name, psSettings[check.slaveOf]) end
    
	parent[name]:SetParent(parent)
end

function PileSeller:PileSeller_MinimapButton_Reposition()
	PileSeller_MinimapButton:SetPoint("TOPLEFT","Minimap","TOPLEFT",52-(80*cos(psSettings["minimapButtonPos"])),(80*sin(psSettings["minimapButtonPos"]))-52)
end

-- Only while the button is dragged this is called every frame
function PileSeller_MinimapButton_DraggingFrame_OnUpdate()

	local xpos,ypos = GetCursorPosition()
	local xmin,ymin = Minimap:GetLeft(), Minimap:GetBottom()

	xpos = xmin-xpos/UIParent:GetScale()+70 -- get coordinates as differences from the center of the minimap
	ypos = ypos/UIParent:GetScale()-ymin-70

	psSettings["minimapButtonPos"] = math.deg(math.atan2(ypos,xpos)) -- save the degrees we are relative to the minimap center
	PileSeller:PileSeller_MinimapButton_Reposition() -- move the button
end

function PileSeller_MinimapButton_OnClick()
	if PileSeller.UIConfig then 
		if PileSeller.UIConfig:IsShown() then 
			HideConfig() 
		else PileSeller:ShowConfig("items")end
	else PileSeller:ShowConfig("items") end
end

function PileSeller_MinimapButton_OnEnter(self)
	GameTooltip:SetOwner(self, "ANCHOR_BOTTOM")
	local s = "|cFFFFFFFFPileSeller|r|n"
	if psSettings["trackSetting"] then
		s = s .. "|cFF00FF00Tracking|r|nGoing to sell " .. #psItems .. " item(s)"
	else 
		s = s .. "|cFFFF0000Not tracking|r" 
	end
	GameTooltip:SetText(s)
end

function PileSeller_MinimapButton_OnLeave(self)
	GameTooltip:Hide()
end